@@ -60,7 +60,7 @@ sub create {
     $self->app_class_file;
     $self->index_template_file;
     $self->css_file;
-    $self->makefile;
+    $self->cpanfile;
     $self->basic_test_file;
     $self->config_file;
 }
@@ -113,7 +113,7 @@ sub app_class_file {
 sub index_template_file {
     my $self = shift;
     my $body = $self->templates->{index_template_file};
-    my $file = File::Spec->catfile($self->approot, qw/view index.tx/);
+    my $file = File::Spec->catfile($self->approot, qw/view index.html/);
     $self->spew($file, $body);
 }
 
@@ -124,16 +124,14 @@ sub css_file {
     $self->spew($file, $body);
 }
 
-sub makefile {
+sub cpanfile {
     my $self = shift;
     my $appname = $self->appname;
     $appname =~ s[::][-]g;
     my $pmpath = $self->pmpath;
     $pmpath =~ s[$appname][.];
-    my $body = $self->templates->{makefile};
-    $body =~ s[\$appname][$appname]g;
-    $body =~ s[\$pmpath][$pmpath]g;
-    my $file = File::Spec->catfile($self->approot, 'Makefile.PL');
+    my $body = $self->templates->{cpanfile};
+    my $file = File::Spec->catfile($self->approot, 'cpanfile');
     $self->spew($file, $body);
 }
 
@@ -193,7 +191,7 @@ our $VERSION = 0.01;
 path '/' => sub {
     my $req = shift;
     return {
-        template => 'index.tx',
+        template => 'index.html',
         title    => config->{appname},
         envname  => config->{envname},
         apppath  => 'lib/' . __PACKAGE__ .'.pm',
@@ -242,23 +240,24 @@ it under the same terms as Perl itself.
 
 index_template_file
 ---
+? my $c = shift;
 <html>
 <head>
   <link rel="stylesheet" href="/static/style.css" />
   <link rel="shortcut icon" href="/static/favicon.ico" />
-  <title><: $title :> - powerd by Nephia</title>
+  <title><?= $c->{title} ?> - powerd by Nephia</title>
 </head>
 <body>
   <div class="title">
-    <span class="title-label"><: $title :></span>
-    <span class="envname"><: $envname :></span>
+    <span class="title-label"><?= $c->{title} ?></span>
+    <span class="envname"><?= $c->{envname} ?></span>
   </div>
 
   <div class="content">
     <h2>Hello, Nephia world!</h2>
     <p>Nephia is a mini web-application framework.</p>
     <pre>
-    ### <: $apppath :>
+    ### <?= $c->{apppath} ?>
     use Nephia;
 
     # <a href="/data">JSON responce sample</a>
@@ -357,32 +356,13 @@ address.generated-by {
 
 ===
 
-makefile
+cpanfile
 ---
-use strict;
-use warnings FATAL => 'all';
-use ExtUtils::MakeMaker;
+requires 'Nephia' => '0';
 
-WriteMakefile(
-    NAME             => '$appname',
-    AUTHOR           => q{clever guy <who@example.com>},
-    VERSION_FROM     => '$pmpath',
-    ABSTRACT_FROM    => '$pmpath',
-    LICENSE          => 'Artistic_2_0',
-    PL_FILES         => {},
-    MIN_PERL_VERSION => 5.008,
-    CONFIGURE_REQUIRES => {
-        'ExtUtils::MakeMaker' => 0,
-    },
-    BUILD_REQUIRES => {
-        'Test::More' => 0,
-    },
-    PREREQ_PM => {
-        'Nephia' => '0',
-    },
-    dist  => { COMPRESS => 'gzip -9f', SUFFIX => 'gz', },
-    clean => { FILES => '$appname-*' },
-);
+on build => sub {
+    requires 'Test::More';
+};
 
 
 ===
